@@ -14,4 +14,14 @@ class TestNSFileProviderError(TestCase):
         self.assertEqual(FileProvider.NSFileProviderErrorInsufficientQuota, -1003)
         self.assertEqual(FileProvider.NSFileProviderErrorServerUnreachable, -1004)
         self.assertEqual(FileProvider.NSFileProviderErrorNoSuchItem, -1005)
-        self.assertEqual(FileProvider.NSFileProviderErrorVersionOutOfDate, -1006)
+        self.assertEqual(FileProvider.NSFileProviderErrorDeletionRejected, -1006)
+        self.assertEqual(FileProvider.NSFileProviderErrorDirectoryNotEmpty, -1007)
+        self.assertEqual(FileProvider.NSFileProviderErrorProviderNotFound, -2001)
+        self.assertEqual(FileProvider.NSFileProviderErrorProviderTranslocated, -2002)
+        self.assertEqual(
+            FileProvider.NSFileProviderErrorOlderExtensionVersionRunning, -2003
+        )
+        self.assertEqual(
+            FileProvider.NSFileProviderErrorNewerExtensionVersionFound, -2004
+        )
+        self.assertEqual(FileProvider.NSFileProviderErrorCannotSynchronize, -2005)
